@@ -46,7 +46,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.6.4"
+VERSION = "0.6.5"
 LOCK_SH = 0
 LOCK_EX = 1
 RUN_PATH = "/run/starrydb/"
@@ -181,8 +181,7 @@ class LibMemcachedClient(pylibmc.ThreadMappedPool):
             return mc.delete(key)
 
 class StarryServer(object):
-    def __init__(self, address, depots=[], cache_size=0, log_file=None, rw_ratio=5):
-        self.address = address
+    def __init__(self, address=None, depots=[], cache_size=0, log_file=None, rw_ratio=5):
         self.cursor = 0
         self.depots = {}
         self.logger = StarryLog(log_file) if log_file is not None else None
@@ -190,7 +189,12 @@ class StarryServer(object):
         self.memcached = None
 
         pathlib.Path(RUN_PATH).mkdir(exist_ok=True)
-        pathlib.Path(SERVER_ADDRESS).write_bytes(msgpack.packb(address))
+
+        if address is None:
+            self.address = SERVER_ADDRESS
+        else:
+            self.address = address
+            pathlib.Path(SERVER_ADDRESS).write_bytes(msgpack.packb(address))
 
         if int(cache_size) > 0:
             try:
@@ -1067,7 +1071,7 @@ class StarryDepot(object):
             self.thread_cond.notify_all()
 
 class StarryClient(object):
-    def __init__(self, path, mode=LOCK_SH, address=None):
+    def __init__(self, path, mode=LOCK_SH, address=SERVER_ADDRESS):
         if address is None:
             address = msgpack.unpackb(pathlib.Path(SERVER_ADDRESS).read_bytes(), use_list=False)
 
